@@ -1,8 +1,9 @@
-__version__ = "0.2.0"
+__author__ = """Clariteia Devs"""
+__email__ = "devs@clariteia.com"
+__version__ = "0.3.3"
 
 from .configuration import (
     BROKER,
-    COMMANDS,
     DISCOVERY,
     QUEUE,
     REPOSITORY,
@@ -72,13 +73,11 @@ from .model import (
     AvroSchemaDecoder,
     AvroSchemaEncoder,
     BucketModel,
-    Command,
-    CommandReply,
-    CommandStatus,
+    DataDecoder,
+    DataEncoder,
     DataTransferObject,
     DeclarativeModel,
     DynamicModel,
-    Event,
     Field,
     GenericTypeProjector,
     MinosModel,
@@ -87,14 +86,12 @@ from .model import (
     ModelField,
     ModelType,
     NoneType,
+    SchemaDecoder,
+    SchemaEncoder,
     TypeHintBuilder,
     TypeHintComparator,
     is_model_type,
 )
-from .networks import (
-    MinosBroker,
-    MinosHandler,
-)
 from .pools import (
     MinosPool,
 )
@@ -105,9 +102,6 @@ from .protocol import (
     MinosBinaryProtocol,
     MinosJsonBinaryProtocol,
 )
-from .saga import (
-    MinosSagaManager,
-)
 from .setup import (
     MinosSetup,
 )
